//
//  ColorsToolError.swift
//  
//
//  Created by Thibaut Schmitt on 20/12/2021.
//

import Foundation

enum ColorsToolError: Error {
    case badFormat(String)
    case writeAsset(String)
    case writeExtension(String, String)
    case fileNotExists(String)
    case badColorDefinition(String, String)
    
    var description: String {
        switch self {
        case .badFormat(let info):
            return "error:[\(Colors.toolName)] Bad line format: \(info). Accepted format are: colorName=\"#RGB/#ARGB\"; colorName \"#RGB/#ARGB\"; colorName \"#RGB/#ARGB\" \"#RGB/#ARGB\""
            
        case .writeAsset(let info):
            return "error:[\(Colors.toolName)] An error occured while writing color in Xcasset: \(info)"
            
        case .writeExtension(let filename, let info):
            return "error:[\(Colors.toolName)] An error occured while writing extension in \(filename): \(info)"
            
        case .fileNotExists(let filename):
            return "error:[\(Colors.toolName)] File \(filename) does not exists"
            
        case .badColorDefinition(let lightColor, let darkColor):
            return "error:[\(Colors.toolName)]One of these two colors has invalid synthax: -\(lightColor)- or -\(darkColor)-"
        }
    }
}
