//
//  ColorExtensionGenerator.swift
//  
//
//  Created by Thibaut Schmitt on 20/12/2021.
//

import Foundation
import ToolCore

struct ColorExtensionGenerator {
    
    let colors: [ParsedColor]
    let extensionClassname: String
    
    static func writeExtensionFile(colors: [ParsedColor], staticVar: Bool, extensionName: String, extensionFilePath: String) {
        // Create file if not exists
        let fileManager = FileManager()
        if fileManager.fileExists(atPath: extensionFilePath) == false {
            Shell.shell(["touch", "\(extensionFilePath)"])
        }
        
        // Create extension content
        let extensionContent = [
            Self.getHeader(extensionClassname: extensionName),
            Self.getProperties(for: colors, withStaticVar: staticVar),
            Self.getFooter()
        ]
            .joined(separator: "\n")
        
        // Write content
        let extensionFilePathURL = URL(fileURLWithPath: extensionFilePath)
        do {
            try extensionContent.write(to: extensionFilePathURL, atomically: true, encoding: .utf8)
        } catch (let error) {
            let error = ColorsToolError.writeExtension(extensionFilePath, error.localizedDescription)
            print(error.localizedDescription)
            Colors.exit(withError: error)
        }
    }
    
    private static func getHeader(extensionClassname: String) -> String {
        """
        // Generated by ResgenSwift.\(Colors.toolName) \(ResgenSwiftVersion)

        import UIKit

        extension \(extensionClassname) {\n
        """
    }
    
    private static func getFooter() -> String {
        """
        }
        """
    }
    
    private static func getProperties(for colors: [ParsedColor], withStaticVar staticVar: Bool) -> String {
        colors.map {
            if staticVar {
                return $0.getColorStaticProperty()
            }
            return $0.getColorProperty()
        }
        .joined(separator: "\n\n")
    }
}
